@@ -51,7 +51,8 @@ namespace ICQ2000 {
    *  @param uin the owner's uin
    *  @param password the owner's password
    */
-  Client::Client(const unsigned int uin, const string& password) : m_password(password), m_recv(&m_translator), m_self(uin) {
+  Client::Client(const unsigned int uin, const string& password)
+    : m_self(uin), m_password(password), m_recv(&m_translator) {
     Init();
   }
 
@@ -232,32 +233,24 @@ namespace ICQ2000 {
   }
 
   void Client::SignalMessage(MessageSNAC *snac) {
-    Contact *contact;
+    Contact *contact = NULL;
     MessageEvent *e = NULL;
     ICQSubType *st = snac->getICQSubType();
     if (st == NULL) return;
 
     unsigned short type = st->getType();
-    if (type == MSG_Type_Normal) {
-      NormalICQSubType *nst = static_cast<NormalICQSubType*>(st);
-      
-      contact = lookupICQ( nst->getSource() );
-      e = new NormalMessageEvent(contact,
-				 nst->getMessage(), nst->isMultiParty() );
-      
-      if (nst->isAdvanced()) SendAdvancedACK(snac);
+    if (type == MSG_Type_Normal
+	|| type == MSG_Type_URL
+	|| type == MSG_Type_AuthReq
+	|| type == MSG_Type_AuthRej
+	|| type == MSG_Type_AuthAcc) {
+      UINICQSubType *ist = static_cast<UINICQSubType*>(st);
+      contact = lookupICQ( ist->getSource() );
+      e = UINICQSubTypeToEvent(ist, contact);
 
-    } else if (type == MSG_Type_URL) {
-      URLICQSubType *ust = static_cast<URLICQSubType*>(st);
-      
-      contact = lookupICQ( ust->getSource() );
-      e = new URLMessageEvent(contact,
-			      ust->getMessage(),
-			      ust->getURL());
-
-      if (ust->isAdvanced()) SendAdvancedACK(snac);
-
-    } else if (type == MSG_Type_SMS) {
+      if (ist->isAdvanced()) SendAdvancedACK(snac);
+    }
+    else if (type == MSG_Type_SMS) {
       SMSICQSubType *sst = static_cast<SMSICQSubType*>(st);
       
       if (sst->getSMSType() == SMSICQSubType::SMS) {
@@ -278,37 +271,8 @@ namespace ICQ2000 {
 				sst->delivered());
       }
 
-    } else if (type == MSG_Type_EmailEx) {
-      EmailExICQSubType *ust = static_cast<EmailExICQSubType*>(st);
-
-      contact = lookupEmail( ust->getEmail() );
-      e = new EmailExEvent(contact, ust->getEmail(), ust->getSender(), ust->getMessage());
-
-    } else if (type == MSG_Type_UserAdd) {
-      UserAddICQSubType *ust = static_cast<UserAddICQSubType*>(st);
-
-      contact = lookupICQ( ust->getSource() );
-      e = new UserAddEvent(contact);
-
-    } else if (type == MSG_Type_AuthReq) {
-      AuthReqICQSubType *ust = static_cast<AuthReqICQSubType*>(st);
-      
-      contact = lookupICQ( ust->getSource() );
-      e = new AuthReqEvent(contact, ust->getMessage());
-
-    } else if (type == MSG_Type_AuthRej) {
-      AuthRejICQSubType *ust = static_cast<AuthRejICQSubType*>(st);
-    
-      contact = lookupICQ( ust->getSource() );
-      e = new AuthAckEvent(contact, ust->getMessage(), false);
-
-    } else if (type == MSG_Type_AuthAcc) {
-      AuthAccICQSubType *ust = static_cast<AuthAccICQSubType*>(st);
-    
-      contact = lookupICQ( ust->getSource() );
-      e = new AuthAckEvent(contact, true);
-
-    } else if (type == MSG_Type_AutoReq_Away
+    }
+    else if (type == MSG_Type_AutoReq_Away
 	       || type == MSG_Type_AutoReq_Occ
 	       || type == MSG_Type_AutoReq_NA
 	       || type == MSG_Type_AutoReq_DND
@@ -339,8 +303,8 @@ namespace ICQ2000 {
     if (e != NULL) {
       contact->addPendingMessage(e);
       if (messaged.emit(e)) {
-	contact->erasePendingMessage(e);
-	SignalMessageQueueChanged(contact);
+        contact->erasePendingMessage(e);
+        SignalMessageQueueChanged(contact);
       }
     }
 
@@ -350,7 +314,6 @@ namespace ICQ2000 {
   void Client::SignalMessageACK(MessageACKSNAC *snac) {
     UINICQSubType *st = snac->getICQSubType();
     if (st == NULL) return;
-    Contact *contact = lookupICQ( st->getSource() );
 
     unsigned char type = st->getType();
     if (type == MSG_Type_AutoReq_Away
@@ -463,24 +426,31 @@ namespace ICQ2000 {
 				ust->getMessage(),
 				ust->getURL(),
 				snac->getTime());
+      } else if (st->getType() == MSG_Type_EmailEx) {
+	EmailExICQSubType *ust = static_cast<EmailExICQSubType*>(st);
+	contact = lookupEmail( ust->getEmail() );
+	e = new EmailExEvent(contact, ust->getEmail(), ust->getSender(), ust->getMessage());
+      } else if (st->getType() == MSG_Type_UserAdd) {
+	UserAddICQSubType *ust = static_cast<UserAddICQSubType*>(st);
+	contact = lookupICQ( ust->getSource() );
+	e = new UserAddEvent(contact);
       } else if (st->getType() == MSG_Type_AuthReq) {
-	AuthReqICQSubType *ust = static_cast<AuthReqICQSubType*>(st);
+        AuthReqICQSubType *ust = static_cast<AuthReqICQSubType*>(st);
 	e = new AuthReqEvent(contact, ust->getMessage(), snac->getTime());
       } else if (st->getType() == MSG_Type_AuthRej) {
-	AuthRejICQSubType *ust = static_cast<AuthRejICQSubType*>(st);
-	e = new AuthAckEvent(contact, ust->getMessage(), false, 
-			     snac->getTime());
+        AuthRejICQSubType *ust = static_cast<AuthRejICQSubType*>(st);
+        e = new AuthAckEvent(contact, ust->getMessage(), false, 
+                             snac->getTime());
       } else if (st->getType() == MSG_Type_AuthAcc) {
-	AuthAccICQSubType *ust = static_cast<AuthAccICQSubType*>(st);
-	e = new AuthAckEvent(contact, true, snac->getTime());
+        e = new AuthAckEvent(contact, true, snac->getTime());
       }
       
       if (e != NULL) {
 	contact->addPendingMessage(e);
-	if (messaged.emit(e)) {
-	  contact->erasePendingMessage(e);
-	  SignalMessageQueueChanged(contact);
-	}
+        if (messaged.emit(e)) {
+          contact->erasePendingMessage(e);
+          SignalMessageQueueChanged(contact);
+        }
       }
       
     } else if (snac->getType() == SrvResponseSNAC::SMS_Error) {
@@ -622,16 +592,16 @@ namespace ICQ2000 {
       try {
 	Contact* c = getUserInfoCacheContact( snac->RequestID() );
 	c->setMainHomeInfo( snac->getMainHomeInfo() );
-	if (c == &m_self)
-	{
-	  MyUserInfoChangeEvent ev(&m_self);
-	  self_event.emit(&ev);
-	}
-	else
-	{
+        if (c == &m_self)
+        {
+          MyUserInfoChangeEvent ev(&m_self);
+          self_event.emit(&ev);
+        }
+        else
+        {
 	  UserInfoChangeEvent ev(c);
 	  contactlist.emit(&ev);
-	}
+        }
       } catch(ParseException e) {
 	SignalLog(LogEvent::WARN, e.what());
       }
@@ -641,16 +611,16 @@ namespace ICQ2000 {
       try {
 	Contact* c = getUserInfoCacheContact( snac->RequestID() );
 	c->setHomepageInfo( snac->getHomepageInfo() );
-	if (c == &m_self)
-	{
-	    MyUserInfoChangeEvent ev(&m_self);
-	    self_event.emit(&ev);
-	}
-	else
-	{
-	    UserInfoChangeEvent ev(c);
-	    contactlist.emit(&ev);
-	}
+        if (c == &m_self)
+        {
+            MyUserInfoChangeEvent ev(&m_self);
+            self_event.emit(&ev);
+        }
+        else
+        {
+            UserInfoChangeEvent ev(c);
+            contactlist.emit(&ev);
+        }
       } catch(ParseException e) {
 	SignalLog(LogEvent::WARN, e.what());
       }
@@ -660,16 +630,16 @@ namespace ICQ2000 {
       try {
 	Contact* c = getUserInfoCacheContact( snac->RequestID() );
 	c->setWorkInfo( snac->getWorkInfo() );
-	if (c == &m_self)
-	{
-	    MyUserInfoChangeEvent ev(&m_self);
-	    self_event.emit(&ev);
-	}
-	else
-	{
-	    UserInfoChangeEvent ev(c);
-	    contactlist.emit(&ev);
-	}
+        if (c == &m_self)
+        {
+            MyUserInfoChangeEvent ev(&m_self);
+            self_event.emit(&ev);
+        }
+        else
+        {
+            UserInfoChangeEvent ev(c);
+            contactlist.emit(&ev);
+        }
       } catch(ParseException e) {
 	SignalLog(LogEvent::WARN, e.what());
       }
@@ -679,16 +649,16 @@ namespace ICQ2000 {
       try {
 	Contact* c = getUserInfoCacheContact( snac->RequestID() );
 	c->setBackgroundInfo( snac->getBackgroundInfo() );
-	if (c == &m_self)
-	{
-	    MyUserInfoChangeEvent ev(&m_self);
-	    self_event.emit(&ev);
-	}
-	else
-	{
-	    UserInfoChangeEvent ev(c);
-	    contactlist.emit(&ev);
-	}
+        if (c == &m_self)
+        {
+            MyUserInfoChangeEvent ev(&m_self);
+            self_event.emit(&ev);
+        }
+        else
+        {
+            UserInfoChangeEvent ev(c);
+            contactlist.emit(&ev);
+        }
       } catch(ParseException e) {
 	SignalLog(LogEvent::WARN, e.what());
       }
@@ -698,16 +668,16 @@ namespace ICQ2000 {
       try {
 	Contact* c = getUserInfoCacheContact( snac->RequestID() );
 	c->setInterestInfo( snac->getPersonalInterestInfo() );
-	if (c == &m_self)
-	{
-	    MyUserInfoChangeEvent ev(&m_self);
-	    self_event.emit(&ev);
-	}
-	else
-	{
-	    UserInfoChangeEvent ev(c);
-	    contactlist.emit(&ev);
-	}
+        if (c == &m_self)
+        {
+            MyUserInfoChangeEvent ev(&m_self);
+            self_event.emit(&ev);
+        }
+        else
+        {
+            UserInfoChangeEvent ev(c);
+            contactlist.emit(&ev);
+        }
       } catch(ParseException e) {
 	SignalLog(LogEvent::WARN, e.what());
       }
@@ -717,16 +687,16 @@ namespace ICQ2000 {
       try {
 	Contact* c = getUserInfoCacheContact( snac->RequestID() );
 	c->setEmailInfo( snac->getEmailInfo() );
-	if (c == &m_self)
-	{
-	    MyUserInfoChangeEvent ev(&m_self);
-	    self_event.emit(&ev);
-	}
-	else
-	{
-	    UserInfoChangeEvent ev(c);
-	    contactlist.emit(&ev);
-	}
+        if (c == &m_self)
+        {
+            MyUserInfoChangeEvent ev(&m_self);
+            self_event.emit(&ev);
+        }
+        else
+        {
+            UserInfoChangeEvent ev(c);
+            contactlist.emit(&ev);
+        }
       } catch(ParseException e) {
 	SignalLog(LogEvent::WARN, e.what());
       }
@@ -736,16 +706,16 @@ namespace ICQ2000 {
       try {
 	Contact* c = getUserInfoCacheContact( snac->RequestID() );
 	c->setAboutInfo( snac->getAboutInfo() );
-	if (c == &m_self)
-	{
-	    MyUserInfoChangeEvent ev(&m_self);
-	    self_event.emit(&ev);
-	}
-	else
-	{
-	    UserInfoChangeEvent ev(c);
-	    contactlist.emit(&ev);
-	}
+        if (c == &m_self)
+        {
+            MyUserInfoChangeEvent ev(&m_self);
+            self_event.emit(&ev);
+        }
+        else
+        {
+            UserInfoChangeEvent ev(c);
+            contactlist.emit(&ev);
+        }
       } catch(ParseException e) {
 	SignalLog(LogEvent::WARN, e.what());
       }
@@ -1018,7 +988,7 @@ namespace ICQ2000 {
 
     if (m_self.isInvisible())
       FLAPwrapSNAC(b, AddVisibleSNAC() );
-	
+        
     SetStatusSNAC sss(Contact::MapStatusToICQStatus(m_self.getStatus(), m_self.isInvisible()));
 
     // explicitly set status to offline. If the user set the status
@@ -1058,6 +1028,7 @@ namespace ICQ2000 {
     ICQSubType *st = snac->getICQSubType();
     if (st == NULL || dynamic_cast<UINICQSubType*>(st) == NULL ) return;
     UINICQSubType *ust = dynamic_cast<UINICQSubType*>(snac->grabICQSubType());
+    ust->setStatus(0); // quick fix until accept-statuses are implemented
 
     SignalLog(LogEvent::INFO, "Sending Advanced Message ACK");
     FLAPwrapSNACandSend( MessageACKSNAC( snac->getICBMCookie(), ust ) );
@@ -1308,14 +1279,14 @@ namespace ICQ2000 {
       switch(snac->Subtype()) {
       case SNAC_SBL_List_From_Server:
 	SignalLog(LogEvent::INFO, "Received server-based list from server\n");
-	SBLListSNAC *sbs = static_cast<SBLListSNAC*>(snac);
-	ContactList l = sbs->getContactList();
-	ContactList::iterator curr = l.begin();
-	while (curr != l.end()) {
-	    if ((*curr).isICQContact()) 
-		SignalServerBasedContact(&(*curr));
-	    ++curr;
-	    }
+        SBLListSNAC *sbs = static_cast<SBLListSNAC*>(snac);
+        ContactList l = sbs->getContactList();
+        ContactList::iterator curr = l.begin();
+        while (curr != l.end()) {
+            if ((*curr).isICQContact()) 
+                SignalServerBasedContact(&(*curr));
+            ++curr;
+            }
 	break;
       }
       break;
@@ -1353,7 +1324,7 @@ namespace ICQ2000 {
 	SignalLog(LogEvent::INFO, ostr.str());
 
 	m_bosHostname = r->getHost();
-	if (!m_bosOverridePort) {
+	if (!m_bosOverridePort)	{
 	  if (r->getPort() != 0) m_bosPort = r->getPort();
 	  else m_bosPort = m_authorizerPort;
 	}
@@ -1628,10 +1599,10 @@ namespace ICQ2000 {
       Status newstat = Contact::MapICQStatusToStatus( ub.getStatus() );
       bool newinvis = Contact::MapICQStatusToInvisible( ub.getStatus() );
       if( m_self.getStatus() != newstat  ||  m_self.isInvisible() != newinvis ) {
-	m_self.setStatus(newstat);
-	m_self.setInvisible(newinvis);
-	MyStatusChangeEvent ev(&m_self);
-	self_event.emit( &ev );
+        m_self.setStatus(newstat);
+        m_self.setInvisible(newinvis);
+        MyStatusChangeEvent ev(&m_self);
+        self_event.emit( &ev );
       }
     }
   }
@@ -1647,7 +1618,6 @@ namespace ICQ2000 {
    *  match messages it has sent up to their acks.
    */
   void Client::SendEvent(MessageEvent *ev) {
-    Contact *c = ev->getContact();
     if (ev->getType() == MessageEvent::Normal
 	|| ev->getType() == MessageEvent::URL
 	|| ev->getType() == MessageEvent::AwayMessage) {
@@ -1785,6 +1755,7 @@ namespace ICQ2000 {
     UINICQSubType *ist = EventToUINICQSubType(ev);
     ist->setAdvanced(true);
     ist->setStatus( Contact::MapStatusToICQStatus(m_self.getStatus(), m_self.isInvisible()) );
+    ist->setDestination( c->getUIN() );
     
     MsgSendSNAC msnac(ist);
     msnac.setAdvanced(true);
@@ -1803,6 +1774,7 @@ namespace ICQ2000 {
     Contact *c = ev->getContact();
     UINICQSubType *ist = EventToUINICQSubType(ev);
     ist->setAdvanced(false);
+    ist->setDestination( c->getUIN() );
     
     MsgSendSNAC msnac(ist);
     msnac.setAdvanced(false);
@@ -1815,42 +1787,6 @@ namespace ICQ2000 {
     messageack.emit(ev);
   }
   
-  UINICQSubType* Client::EventToUINICQSubType(MessageEvent *ev)
-  {
-    Contact *c = ev->getContact();
-    UINICQSubType *ist = NULL;
-
-    if (ev->getType() == MessageEvent::Normal) {
-
-      NormalMessageEvent *nv = static_cast<NormalMessageEvent*>(ev);
-      ist = new NormalICQSubType(nv->getMessage(), c->getUIN());
-
-    } else if (ev->getType() == MessageEvent::URL) {
-
-      URLMessageEvent *uv = static_cast<URLMessageEvent*>(ev);
-      ist = new URLICQSubType(uv->getMessage(), uv->getURL(), m_self.getUIN(), c->getUIN());
-
-    } else if (ev->getType() == MessageEvent::AwayMessage) {
-
-      ist = new AwayMsgSubType( c->getStatus(), c->getUIN() );
-
-    } else if (ev->getType() == MessageEvent::AuthReq) {
-
-      AuthReqEvent *uv = static_cast<AuthReqEvent*>(ev);
-      ist = new AuthReqICQSubType(uv->getMessage(), m_self.getUIN(), c->getUIN());
-
-    } else if (ev->getType() == MessageEvent::AuthAck) {
-
-      AuthAckEvent *uv = static_cast<AuthAckEvent*>(ev);
-      if(uv->isGranted())
-	ist = new AuthAccICQSubType(m_self.getUIN(), c->getUIN());
-      else
-	ist = new AuthRejICQSubType(uv->getMessage(), m_self.getUIN(), c->getUIN());
-
-    }
-    return ist;
-  }
-
   void Client::PingServer() {
     Buffer b(&m_translator);
     Buffer::marker mk = FLAPHeader(b,0x05);
@@ -1861,14 +1797,14 @@ namespace ICQ2000 {
 
     void Client::uploadSelfDetails()
   {
-	Buffer b(&m_translator);
-	
-	FLAPwrapSNAC( b, SrvUpdateMainHomeInfo(m_self.getUIN(), m_self.getMainHomeInfo()) );
-	FLAPwrapSNAC( b, SrvUpdateWorkInfo(m_self.getUIN(), m_self.getWorkInfo()) );
-	FLAPwrapSNAC( b, SrvUpdateHomepageInfo(m_self.getUIN(), m_self.getHomepageInfo()) );
-	FLAPwrapSNAC( b, SrvUpdateAboutInfo(m_self.getUIN(), m_self.getAboutInfo()) );
+        Buffer b(&m_translator);
+        
+        FLAPwrapSNAC( b, SrvUpdateMainHomeInfo(m_self.getUIN(), m_self.getMainHomeInfo()) );
+        FLAPwrapSNAC( b, SrvUpdateWorkInfo(m_self.getUIN(), m_self.getWorkInfo()) );
+        FLAPwrapSNAC( b, SrvUpdateHomepageInfo(m_self.getUIN(), m_self.getHomepageInfo()) );
+        FLAPwrapSNAC( b, SrvUpdateAboutInfo(m_self.getUIN(), m_self.getAboutInfo()) );
 
-	Send(b);
+        Send(b);
   }
     
   /**
@@ -2018,6 +1954,7 @@ namespace ICQ2000 {
     }
     return &(m_contact_list[m]);
   }
+  
 
   void Client::SignalServerBasedContact(Contact *c) {
     ServerBasedContactEvent ev(c);
@@ -2152,8 +2089,7 @@ namespace ICQ2000 {
   SearchResultEvent* Client::searchForContacts
     (const string& nickname, const string& firstname,
      const string& lastname, const string& email,
-     unsigned short min_age, unsigned short max_age,
-     Sex sex, unsigned char language, const string& city,
+     AgeRange age, Sex sex, unsigned char language, const string& city,
      const string& state, unsigned short country,
      const string& company_name, const string& department,
      const string& position, bool only_online)
@@ -2163,6 +2099,38 @@ namespace ICQ2000 {
     unsigned int reqid = NextRequestID();
     m_reqidcache.insert( reqid, new SearchCacheValue( ev ) );
 
+    unsigned short min_age, max_age;
+
+    switch(age) {
+	case range_18_22:
+	    min_age = 18;
+	    max_age = 22;
+	    break;
+	case range_23_29:
+	    min_age = 23;
+	    max_age = 29;
+	    break;
+	case range_30_39:
+	    min_age = 30;
+	    max_age = 39;
+	    break;
+	case range_40_49:
+	    min_age = 40;
+	    max_age = 49;
+	    break;
+	case range_50_59:
+	    min_age = 50;
+	    max_age = 59;
+	    break;
+	case range_60_above:
+	    min_age = 60;
+	    max_age = 0x2710;
+	    break;
+	default:
+	    min_age = max_age = 0;
+	    break;
+    }
+
     SrvRequestFullWP ssnac( m_self.getUIN(), nickname, firstname, lastname, email,
 			    min_age, max_age, (unsigned char)sex, language, city, state,
 			    country, company_name, department, position,
@@ -2204,7 +2172,7 @@ namespace ICQ2000 {
     if (m_state == NOT_CONNECTED) return;
 
     if (m_state == AUTH_AWAITING_CONN_ACK || m_state == AUTH_AWAITING_AUTH_REPLY|| 
-	m_state == UIN_AWAITING_CONN_ACK || m_state == UIN_AWAITING_UIN_REPLY) {
+        m_state == UIN_AWAITING_CONN_ACK || m_state == UIN_AWAITING_UIN_REPLY) {
       DisconnectAuthorizer();
     } else {
       DisconnectBOS();
