@@ -48,10 +48,10 @@ namespace ICQ2000 {
   DirectClient::DirectClient(Contact& self, TCPSocket *sock, ContactList *cl,
 			     unsigned int ext_ip, unsigned short server_port,
 			     Translator* translator)
-    : m_self_contact(self), m_socket(sock), m_state(WAITING_FOR_INIT),
-      m_local_ext_ip(ext_ip),
-      m_local_server_port(server_port),m_translator(translator), 
-      m_recv(translator), m_contact_list(cl), m_incoming(true), m_contact(NULL)
+    : m_state(WAITING_FOR_INIT), m_socket(sock), m_recv(translator),
+      m_self_contact(self), m_contact(NULL), m_contact_list(cl),
+      m_incoming(true), m_local_ext_ip(ext_ip),
+      m_local_server_port(server_port), m_translator(translator)
   {
     Init();
   }
@@ -61,10 +61,10 @@ namespace ICQ2000 {
    */
   DirectClient::DirectClient(Contact& self, Contact *c, unsigned int ext_ip,
 			     unsigned short server_port, Translator *translator)
-    : m_self_contact(self), m_state(NOT_CONNECTED),
-      m_local_ext_ip(ext_ip), m_local_server_port(server_port),
-      m_translator(translator), m_recv(translator), m_incoming(false),
-      m_contact(c)
+    : m_state(NOT_CONNECTED), m_recv(translator), m_self_contact(self), 
+      m_contact(c), m_incoming(false), m_local_ext_ip(ext_ip),
+      m_local_server_port(server_port), m_translator(translator)
+      
   {
     Init();
     m_socket = new TCPSocket();
@@ -434,9 +434,8 @@ namespace ICQ2000 {
     b >> length;
 
     // we should get the decrypted packet in
-    unsigned int checksum, foreground, background;
-    unsigned short command, seqnum, unknown, ackFlags, msgFlags, version;
-    unsigned char subCommand, flags;
+    unsigned int checksum;
+    unsigned short command, seqnum, unknown, version;
     unsigned char junk;
     string msg;
     ostringstream ostr;
@@ -470,19 +469,14 @@ namespace ICQ2000 {
 
     case V6_TCP_START:
 
-      if (type == MSG_Type_Normal) {
-	NormalICQSubType *nst = static_cast<NormalICQSubType*>(icqsubtype);
-	ev = new NormalMessageEvent(m_contact, nst->getMessage(), nst->isMultiParty());
+      if (type == MSG_Type_Normal
+	  || type == MSG_Type_URL) {
+	UINICQSubType *ist = static_cast<UINICQSubType*>(icqsubtype);
+	ev = UINICQSubTypeToEvent(ist,m_contact);
 	SignalMessageEvent(ev);
 
 	SendPacketAck(icqsubtype);
 
-      } else if (type == MSG_Type_URL) {
-	URLICQSubType *ust = static_cast<URLICQSubType*>(icqsubtype);
-	ev = new URLMessageEvent(m_contact, ust->getMessage(), ust->getURL());
-	SignalMessageEvent(ev);
-
-	SendPacketAck(icqsubtype);
       } else if (type == MSG_Type_AutoReq_Away
 	       || type == MSG_Type_AutoReq_Occ
 	       || type == MSG_Type_AutoReq_NA
@@ -705,6 +699,8 @@ namespace ICQ2000 {
       << (unsigned int)0x00000000
       << (unsigned int)0x00000000;
     icqsubtype->setACK(true);
+    icqsubtype->setStatus(0); // quick fix until accept-statuses are implemented
+    
     icqsubtype->Output(b);
     Buffer c(m_translator);
     Encrypt(b,c);
@@ -716,18 +712,7 @@ namespace ICQ2000 {
 
     unsigned short seqnum = NextSeqNum();
 
-    Contact *co = ev->getContact();
-
-    UINICQSubType *ist = NULL;
-    if (ev->getType() == MessageEvent::Normal) {
-      NormalMessageEvent *nv = static_cast<NormalMessageEvent*>(ev);
-      ist = new NormalICQSubType(nv->getMessage(), co->getUIN());
-    } else if (ev->getType() == MessageEvent::URL) {
-      URLMessageEvent *uv = static_cast<URLMessageEvent*>(ev);
-      ist = new URLICQSubType(uv->getMessage(), uv->getURL(), m_self_contact.getUIN(), co->getUIN());
-    } else if (ev->getType() == MessageEvent::AwayMessage) {
-      ist = new AwayMsgSubType( co->getStatus(), co->getUIN() );
-    }
+    UINICQSubType *ist = EventToUINICQSubType(ev);
     if (ist == NULL) return;
 
     ist->setAdvanced(true);
