@@ -1,7 +1,7 @@
 /*
 *
 * centericq core routines
-* $Id: centericq.cc,v 1.66 2002/01/22 11:59:15 konst Exp $
+* $Id: centericq.cc,v 1.68 2002/02/07 17:33:55 konst Exp $
 *
 * Copyright (C) 2001 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -266,6 +266,18 @@ void centericq::mainloop() {
 		history(c->getdesc());
 		break;
 
+	    case ACT_FETCHAWAY:
+		{
+		    abstracthook &hook = gethook(c->getdesc().pname);
+
+		    if(hook.getstatus() != offline) {
+			hook.requestawaymsg(c->getdesc());
+		    } else {
+			face.log(_("+ cannot fetch away messages being offline"));
+		    }
+		}
+		break;
+
 	    case ACT_MSG:
 	    case 0:
 		if(c->getmsgcount()) {
