@@ -9,7 +9,8 @@ enum hookcapabilities {
     hoptCanNotify = 2,
     hoptCanSendURL = 4,
     hoptCanSendFile = 8,
-    hoptCanSendSMS = 16
+    hoptCanSendSMS = 16,
+    hoptCanSetAwayMsg = 32,
 };
 
 class abstracthook {
@@ -53,6 +54,8 @@ class abstracthook {
 	virtual void lookup(const imsearchparams &params, verticalmenu &dest);
 	virtual void stoplookup();
 
+	virtual void requestawaymsg(const imcontact &c);
+
 	int getcapabilities() const;
 };
 
