@@ -36,6 +36,7 @@ class icqhook: public abstracthook, public SigC::Object {
 
 	void resolve();
 	void sendinvisible();
+	void updateinforecord(Contact *ic, icqcontact *c);
 
     public:
 	icqhook();
@@ -63,6 +64,7 @@ class icqhook: public abstracthook, public SigC::Object {
 	imstatus getstatus() const;
 
 	void requestinfo(const imcontact c);
+	void requestawaymsg(const imcontact &c);
 
 	bool regconnect(const string aserv);
 	bool regattempt(unsigned int &auin, const string apassword);
