@@ -19,12 +19,12 @@
 #include "kkstrtext.h"
 #include "conf.h"
 
-#define PERIOD_RECONNECT        30
+#define PERIOD_RECONNECT        40
 
 #ifdef ENABLE_NLS
 
 #include <libintl.h>
-#define _(s)    gettext(s)
+#define _(s)    ::gettext(s)
 
 #else
 
