@@ -1,7 +1,7 @@
 /*
 *
 * centericq user interface class, dialogs related part
-* $Id: icqdialogs.cc,v 1.45 2002/01/23 16:31:23 konst Exp $
+* $Id: icqdialogs.cc,v 1.50 2002/02/07 17:33:55 konst Exp $
 *
 * Copyright (C) 2001 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -93,8 +93,7 @@ bool icqface::finddialog(imsearchparams &s) {
 		tree.addleaff(i, 0, 13, _(" First name : %s "), s.firstname.c_str());
 		tree.addleaff(i, 0, 14, _(" Last name : %s "), s.lastname.c_str());
 
-		tree.addleaff(i, 0, 15, _(" Min. age : %s "), strint(s.minage));
-		tree.addleaff(i, 0, 16, _(" Max. age : %s "), strint(s.maxage));
+		tree.addleaff(i, 0, 15, _(" Age range : %s "), stragerange[s.agerange]);
 		tree.addleaff(i, 0, 17, _(" Gender : %s "), strgender[s.gender]);
 		tree.addleaff(i, 0, 18, _(" Language : %s "), strlanguage(s.language));
 
@@ -138,8 +137,7 @@ bool icqface::finddialog(imsearchparams &s) {
 		    case 12: s.email = inputstr(_("E-Mail: "), s.email); break;
 		    case 13: s.firstname = inputstr(_("First name: "), s.firstname); break;
 		    case 14: s.lastname = inputstr(_("Last name: "), s.lastname); break;
-		    case 15: s.minage = atol(inputstr(_("Minimal age: "), strint(s.minage)).c_str()); break;
-		    case 16: s.maxage = atol(inputstr(_("Maximal age: "), strint(s.maxage)).c_str()); break;
+		    case 15: selectagerange(s.agerange); break;
 		    case 17: selectgender(s.gender); break;
 		    case 18: selectlanguage(s.language); break;
 		    case 19: s.city = inputstr(_("City: "), s.city); break;
@@ -195,7 +193,7 @@ void icqface::gendetails(treeview *tree, icqcontact *c = 0) {
     tree->addleaff(i, 0, 18, _(" State : %s "), bi.state.c_str());
     tree->addleaff(i, 0, 19, _(" Country : %s "), strcountry(bi.country));
     tree->addleaff(i, 0, 20, _(" Street address : %s "), bi.street.c_str());
-    tree->addleaff(i, 0, 21, _(" Zip code : %s "), strint(bi.zip));
+    tree->addleaff(i, 0, 21, _(" Zip code : %s "), bi.zip.c_str());
     tree->addleaff(i, 0, 22, _(" Phone : %s "), bi.phone.c_str());
     tree->addleaff(i, 0, 23, _(" Fax : %s "), bi.fax.c_str());
     tree->addleaff(i, 0, 24, _(" Cellular phone : %s "), bi.cellular.c_str());
@@ -329,7 +327,7 @@ bool icqface::updatedetails(icqcontact *c = 0) {
 		case 18: bi.state = inputstr(_("State: "), bi.state); break;
 		case 19: selectcountry(bi.country); break;
 		case 20: bi.street = inputstr(_("Street address: "), bi.street); break;
-		case 21: bi.zip = strtoul(inputstr(_("Zip code: "), strint(bi.zip)).c_str(), 0, 0); break;
+		case 21: bi.zip = inputstr(_("Zip code: "), bi.zip); break;
 		case 22: bi.phone = inputstr(_("Phone: "), bi.phone); break;
 		case 23: bi.fax = inputstr(_("Fax: "), bi.fax); break;
 		case 24: bi.cellular = inputstr(_("Cellular phone: "), bi.cellular); break;
@@ -351,7 +349,7 @@ bool icqface::updatedetails(icqcontact *c = 0) {
 		case 37: selectlanguage(mi.lang2); break;
 		case 38: selectlanguage(mi.lang3); break;
 
-		case 39: editabout(about); break;
+		case 39: edit(about, _("About")); break;
 		case 40: bi.requiresauth = !bi.requiresauth; break;
 	    }
 
@@ -426,10 +424,30 @@ void icqface::selectgender(imgender &f) {
     if(i) f = (imgender) ((int) m.getref(i-1));
 }
 
-void icqface::editabout(string &fabout) {
+void icqface::selectagerange(ICQ2000::AgeRange &r) {
+    verticalmenu m(conf.getcolor(cp_dialog_menu), conf.getcolor(cp_dialog_selected));
+    m.setwindow(textwindow(4, LINES-8, 18, LINES-3, conf.getcolor(cp_dialog_menu)));
+
+    for(ICQ2000::AgeRange i = ICQ2000::range_NoRange; i <= ICQ2000::range_60_above; (int) i += 1) {
+	const char *p = stragerange[i];
+
+	if(i == ICQ2000::range_NoRange)
+	    p = _("none");
+
+	m.additemf(0, (int) i, " %s", p);
+	if(i == r) m.setpos(m.getcount()-1);
+    }
+
+    int i = m.open();
+    m.close();
+
+    if(i) r = (ICQ2000::AgeRange) ((int) m.getref(i-1));
+}
+
+bool icqface::edit(string &txt, const string header) {
     texteditor se;
     textwindow w(0, 0, DIALOG_WIDTH, DIALOG_HEIGHT, conf.getcolor(cp_dialog_frame), TW_CENTERED);
-    w.set_title(conf.getcolor(cp_dialog_highlight), _(" About [Ctrl-X save, Esc cancel] "));
+    w.set_title(conf.getcolor(cp_dialog_highlight), (string) " " + header + _(" [Ctrl-X save, Esc cancel] "));
     w.open();
 
     editdone = false;
@@ -439,16 +457,17 @@ void icqface::editabout(string &fabout) {
     se.otherkeys = &editaboutkeys;
     se.wrap = true;
 
-    se.load(fabout, "");
+    se.load(txt, "");
     se.open();
 
     if(editdone) {
 	char *ctext = se.save("\r\n");
-	fabout = ctext;
+	txt = ctext;
 	delete ctext;
     }
 
     w.close();
+    return editdone;
 }
 
 bool icqface::sendfiles(const imcontact cinfo, string &msg, linkedlist &flist) {
@@ -575,17 +594,16 @@ bool icqface::updateconf(icqconf::regsound &s, icqconf::regcolor &c) {
 	t.addleaff(i, 0, 14, _(" Anti-spam: kill msgs from users not on the list : %s "), stryesno[antispam]);
 	t.addleaff(i, 0,  8, _(" Quote a message on reply : %s "), stryesno[quote]);
 	t.addleaff(i, 0, 15, _(" Check the local mailbox : %s "), stryesno[mailcheck]);
-//        t.addleaff(i, 0, 16, _(" Send all events through server : %s "), stryesno[serveronly]);
 	t.addleaff(i, 0, 13, _(" Remember passwords : %s "), stryesno[savepwd]);
-
+/*
 	i = t.addnode(_(" Communications "));
 	t.addleaff(i, 0, 9, _(" Use SOCKS proxy : %s "), stryesno[socks]);
-
+*/
 	i = t.addnode(_(" Miscellaneous "));
 	t.addleaff(i, 0, 4, _(" Automatically set Away period (min) : %d "), aaway);
 	t.addleaff(i, 0, 5, _(" Automatically set N/A period (min) : %d "), ana);
 	t.addleaff(i, 0, 18, _(" Detailed IM events log in ~/.centericq/log : %s "), stryesno[makelog]);
-
+/*
 	if(socks) {
 	    conf.getsocksuser(socksuser, sockspass);
 	    i = t.addnode(_(" SOCKS proxy settings "));
@@ -593,7 +611,7 @@ bool icqface::updateconf(icqconf::regsound &s, icqconf::regcolor &c) {
 	    t.addleaff(i, 0, 11, _(" Proxy user name : %s "), socksuser.c_str());
 	    t.addleaff(i, 0, 12, _(" Proxy password : %s "), phidden.assign(sockspass.size(), '*').c_str());
 	}
-
+*/
 	void *p;
 	finished = !db.open(n, b, &p);
 	i = (int) p;
