@@ -1,7 +1,7 @@
 /*
 *
 * centericq user interface class
-* $Id: icqface.cc,v 1.75 2002/01/31 18:03:26 konst Exp $
+* $Id: icqface.cc,v 1.81 2002/02/13 15:42:34 konst Exp $
 *
 * Copyright (C) 2001 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -46,8 +46,15 @@ const char *strregcolor(icqconf::regcolor c) {
 }
 
 const char *strint(unsigned int i) {
-    static string s;
-    return i ? (s = i2str(i)).c_str() : "";
+    static char buf[64];
+
+    if(i) {
+	sprintf(buf, "%lu", i);
+    } else {
+	buf[0] = 0;
+    }
+
+    return buf;
 }
 
 const char *strcountry(unsigned int code) {
@@ -208,6 +215,10 @@ int icqface::contextmenu(icqcontact *c) {
 
 	m.additem(0, ACT_INFO, _(" User's details         ?"));
 	m.additem(0, ACT_EDITUSER, _(" Edit details"));
+
+	if(c->getstatus() != offline)
+	if(capab & hoptCanSetAwayMsg)
+	    m.additem(0, ACT_FETCHAWAY, _(" Fetch away message"));
     }
 
     m.additem(0, ACT_HISTORY, _(" Events history         h"));
@@ -657,7 +668,7 @@ void icqface::infohome(dialogbox &db, icqcontact *c) {
     x += 10;
     mainw.write(x, WORKAREA_Y1+2, conf.getcolor(cp_main_text), bi.street);
     mainw.write(x, WORKAREA_Y1+3, conf.getcolor(cp_main_text), bi.city);
-    mainw.write(x, WORKAREA_Y1+4, conf.getcolor(cp_main_text), bi.zip ? i2str(bi.zip) : "");
+    mainw.write(x, WORKAREA_Y1+4, conf.getcolor(cp_main_text), bi.zip);
     mainw.write(x, WORKAREA_Y1+5, conf.getcolor(cp_main_text), bi.phone);
     mainw.write(x, WORKAREA_Y1+6, conf.getcolor(cp_main_text), bi.fax);
     mainw.write(x, WORKAREA_Y1+7, conf.getcolor(cp_main_text), bi.cellular);
@@ -701,7 +712,7 @@ void icqface::infowork(dialogbox &db, icqcontact *c) {
 
     mainw.write(WORKAREA_X1+14, WORKAREA_Y1+2, conf.getcolor(cp_main_text), wi.street);
     mainw.write(WORKAREA_X1+14, WORKAREA_Y1+3, conf.getcolor(cp_main_text), wi.city);
-    mainw.write(WORKAREA_X1+14, WORKAREA_Y1+4, conf.getcolor(cp_main_text), wi.zip ? i2str(wi.zip) : "");
+    mainw.write(WORKAREA_X1+14, WORKAREA_Y1+4, conf.getcolor(cp_main_text), wi.zip);
     mainw.write(WORKAREA_X1+14, WORKAREA_Y1+6, conf.getcolor(cp_main_text), wi.company);
     mainw.write(WORKAREA_X1+14, WORKAREA_Y1+7, conf.getcolor(cp_main_text), wi.dept);
     mainw.write(WORKAREA_X1+14, WORKAREA_Y1+8, conf.getcolor(cp_main_text), wi.position);
@@ -1395,7 +1406,7 @@ void icqface::extracturls(const string buf) {
     const char *pp = buf.c_str();
 
     extractedurls.clear();
-    if(!regcomp(&r, "(http://[^ ,\t\n]+|ftp://[^, \t\n]+|www\\.[^, \t\n]+)", REG_EXTENDED)) {
+    if(!regcomp(&r, "(http://[^ ,\t\n]+|https://[^ ,\t\n]+|ftp://[^, \t\n]+|www\\.[^, \t\n]+)", REG_EXTENDED)) {
 	while(!regexec(&r, buf.substr(pos).c_str(), 1, rm, 0)) {
 	    extractedurls.push_back(buf.substr(pos+rm[0].rm_so, rm[0].rm_eo-rm[0].rm_so));
 	    pos += rm[0].rm_eo;
