@@ -57,6 +57,7 @@
 #define ACT_GROUPMOVE   -34
 #define ACT_ORG_GROUPS  -35
 #define ACT_HIDEOFFLINE -36
+#define ACT_FETCHAWAY   -37
 
 extern class centericq cicq;
 
@@ -128,8 +129,7 @@ class icqface {
 
 	void selectcountry(unsigned short &f);
 	void selectlanguage(unsigned short &f);
-
-	void editabout(string &fabout);
+	void selectagerange(ICQ2000::AgeRange &r);
 
 	void saveworkarea();
 	void restoreworkarea();
@@ -205,6 +205,8 @@ class icqface {
 
 	bool eventedit(imevent &ev);
 	eventviewresult eventview(const imevent *ev);
+
+	bool edit(string &txt, const string header);
 };
 
 extern icqface face;
@@ -228,6 +230,16 @@ static const char *strgender[imgender_size] = {
     _("Female")
 };
 
+static const char *stragerange[ICQ2000::range_60_above+1] = {
+  "",
+  "18-22",
+  "23-29",
+  "30-39",
+  "40-49",
+  "50-59",
+  _("60-above")
+};
+
 static const char *eventviewresultnames[icqface::eventviewresult_size] = {
     "", _("Fwd"), _("Reply"), _("Ok"),
     _("Open"), _("Accept"), _("Reject")
